summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoStyleManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoStyleManager.h')
-rw-r--r--lib/kotext/KoStyleManager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kotext/KoStyleManager.h b/lib/kotext/KoStyleManager.h
index 328668fd..af848e1d 100644
--- a/lib/kotext/KoStyleManager.h
+++ b/lib/kotext/KoStyleManager.h
@@ -123,7 +123,7 @@ class KOTEXT_EXPORT KoStyleManagerTab : public TQWidget {
Q_OBJECT
TQ_OBJECT
public:
- KoStyleManagerTab(TQWidget *tqparent) : TQWidget(tqparent) {};
+ KoStyleManagerTab(TQWidget *parent) : TQWidget(parent) {};
/** the new style which is to be displayed */
void setStyle(KoParagStyle *style) { m_style = style; }
@@ -144,9 +144,9 @@ class KOTEXT_EXPORT KoStyleParagTab : public KoStyleManagerTab
Q_OBJECT
TQ_OBJECT
public:
- KoStyleParagTab( TQWidget * tqparent );
+ KoStyleParagTab( TQWidget * parent );
- // not a constructor parameter since 'this' is the tqparent of the widget
+ // not a constructor parameter since 'this' is the parent of the widget
void setWidget( KoParagLayoutWidget * widget );
virtual void update();
@@ -164,7 +164,7 @@ class KOTEXT_EXPORT KoStyleFontTab : public KoStyleManagerTab
Q_OBJECT
TQ_OBJECT
public:
- KoStyleFontTab( TQWidget * tqparent );
+ KoStyleFontTab( TQWidget * parent );
~KoStyleFontTab();
virtual void update();
virtual TQString tabName();